@@ -12,8 +12,8 @@ use rollo::{
     error::Error,
     packet::Packet,
     server::{
-        world::WorldI,
-        world_session::{SocketTools, WorldSessionI},
+        world::World,
+        world_session::{SocketTools, WorldSession},
         world_socket_mgr::{ListenerSecurity, WorldSocketMgr},
     },
 };
@@ -72,7 +72,7 @@ struct MyWorldSession {
 }
 
 #[async_trait]
-impl WorldSessionI<MyWorld> for MyWorldSession {
+impl WorldSession<MyWorld> for MyWorldSession {
     async fn on_open(
         tools: SocketTools,
         _world: &'static MyWorld,
@@ -91,7 +91,7 @@ impl WorldSessionI<MyWorld> for MyWorldSession {
     async fn on_message(world_session: &Arc<Self>, _world: &'static MyWorld, packet: Packet) {
         world_session
             .socket_tools
-            .send(packet.cmd, Some(packet.payload.unwrap()));
+            .send(packet.cmd, Some(&packet.payload.unwrap()));
     }
 
     async fn on_close(_world_session: &Arc<Self>, _world: &'static MyWorld) {}
@@ -101,7 +101,7 @@ struct MyWorld {
     elapsed: AtomicU64,
 }
 
-impl WorldI for MyWorld {
+impl World for MyWorld {
     type WorldSessionimplementer = MyWorldSession;
     fn time(&self) -> i64 {
         self.elapsed.load(Ordering::Acquire) as i64
